import warnings


def warn_function_is_work_in_progress():
    """

    This function is a work in progress.

    """
    warnings.warn(
        "This function is currently a work in progress and is liable to change."
    )
